"""template-specific forms/views/actions/components"""
from cubicweb.web import uicfg, formwidgets as fw
from cubicweb.web.views.urlrewrite import SimpleReqRewriter, rgx

_afs = uicfg.autoform_section
_afs.tag_attribute(('WorkOrder', 'progress_target'), 'main', 'hidden')
_afs.tag_attribute(('WorkOrder', 'progress_todo'), 'main', 'hidden')
_afs.tag_attribute(('WorkOrder', 'progress_done'), 'main', 'hidden')
_afs.tag_subject_of(('WorkOrder', 'uses_technology', '*'), 'main', 'attributes')
_afs.tag_subject_of(('WorkOrder', 'uses_technology', '*'), 'muledit', 'attributes')
_afs.tag_subject_of(('Resource', 'use_calendar', '*'), 'main', 'inlined')
# XXX should not be always hidden
uicfg.autoform_field_kwargs.tag_subject_of(('Activity', 'done_by', '*'),
                                           {'widget': fw.HiddenInput})


uicfg.primaryview_section.tag_object_of(('*', 'use_calendar', 'Calendar'), 'hidden')

uicfg.actionbox_appearsin_addmenu.tag_subject_of(('Resource', 'has_vacation', '*'), True)
uicfg.actionbox_appearsin_addmenu.tag_object_of(('Resource', 'euser', 'CWUser'), True)


class TimesheetReqRewriter(SimpleReqRewriter):
    rules = [
        (rgx('/activities/(.*?)/(\d{4})-(\d\d)-(\d\d)'),
         dict(year=r'\2', month=r'\3', day=r'\4',
              vid='activities-submit',
              rql=r'Any A WHERE A is Activity, A diem "\2-\3-\4", A done_by R, '
              r'R euser U, U login "\1"')),
        ]



from datetime import timedelta

from logilab.common.date import date_range, todate

from cubicweb.entities import AnyEntity, fetch_config, authobjs

from cubes.workorder.entities import Order, WorkOrder
from cubes.calendar.entities import intersect

class Activity(AnyEntity):
    __regid__ = 'Activity'
    fetch_attrs, fetch_order = fetch_config(['diem', 'done_for', 'duration'])

    @property
    def user(self):
        return self.done_by[0].user

    def dc_title(self, format="text/plain"):
        duration = self.duration
        if self.user:
            login = self.user.login
        else:
            login = u''
        try:
            return u'%s %s %s %s [%s]' % (
                self._cw.format_date(self.diem), login, duration,
                self.wp[0].dc_title(),
                self.cw_adapt_to('IWorkflowable').printable_state)
        except:
            # remote sources unavailable or no related wp
            return u'%s %s %s [%s]' % (
                self._cw.format_date(self.diem), login, duration,
                self.cw_adapt_to('IWorkflowable').printable_state)

    def dc_long_title(self):
        return u'%s %s' % (self.dc_title(), self.description)



class TimesheetCWUserMixIn(object):

    @property
    def default_resource(self):
        if self.reverse_euser:
            return self.reverse_euser[0]
        return None


class TimesheetCWUser(TimesheetCWUserMixIn, authobjs.CWUser):
    pass


AWHERE = ('WHERE A is Activity, A diem DI, A duration DU, A description DE, '
          'A done_by R, A in_state S, A done_for WO, O split_into WO, ')
ADETAILS = 'Any A, DI, R, DU, WO, DE, S ORDERBY DI,R ' + AWHERE
A_BY_R = 'Any R, S, SUM(DU), MIN(DI), MAX(DI) GROUPBY R,S ORDERBY S ' + AWHERE
A_BY_W = 'Any WO, S, SUM(DU), MIN(DI), MAX(DI) GROUPBY WO, S ORDERBY S ' + AWHERE

class Resource(AnyEntity):
    __regid__ = 'Resource'
    rest_attr = 'title'
    fetch_attrs, fetch_order = fetch_config(('title',))

    rql_activities = ADETAILS+'R eid %(eid)s'
    rql_activities_groupby_workorder = A_BY_W + 'R eid %(eid)s'

    def dc_title(self):
        return '%s' % (self.title)

    def dc_long_title(self):
        return '%s (%s)' % (self.title, self.rtype[0].title)

    @property
    def calendars(self):
        return [cuse.use_calendar[0] for cuse in self.use_calendar]

    @property
    def user(self):
        if self.euser:
            return self.euser[0]
        return None

    def get_day_types(self, start, stop):
        day_types = []
        cuses = []
        for cuse in self.use_calendar:
            cstart = cuse.start or start
            cstart = todate(cstart)
            cstop = cuse.stop or stop
            cstop = todate(cstop)
            if intersect((start, stop), (cstart, cstop)):
                cuses.append( (cstart, cstop, cuse) )
        for date in date_range(start, stop + timedelta(days=1)):
            for cstart, cstop, cuse in cuses:
                if cstart <= date <= cstop:
                    day_types.append(cuse.use_calendar[0].get_days_type(date, date)[0])
                    break
        return day_types


class TimesheetOrder(Order):
    rest_attr = 'title'

    rql_activities_groupby_resource = A_BY_R+'O eid %(eid)s'
    rql_activities = ADETAILS+'O eid %(eid)s'

class TimesheetWorkOrder(WorkOrder):

    rql_activities_groupby_resource = A_BY_R+'WO eid %(eid)s'
    rql_activities = ADETAILS+'WO eid %(eid)s'
    open_state = 'in progress'

    def contractors(self):
        return self.todo_by

    def _compute_progress(self):
        self.progress_target = self.budget or 0
        self.progress_done = sum(activity.duration for activity in self.reverse_done_for)
        self.progress_todo = max(0, self.progress_target - self.progress_done)

    # number of columns to display
    activities_rql_nb_displayed_cols = 10
    def activities_rql(self, limit=None):
        return ADETAILS+'WO eid %(eid)s'



"""gingouz specific boxes

:organization: Logilab
:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
"""
__docformat__ = "restructuredtext en"

from logilab.mtconverter import xml_escape

from cubicweb.web.box import BoxTemplate
from cubicweb.web.htmlwidgets import BoxWidget, BoxHtml

class ActivitiesBox(BoxTemplate):
    """display a box with an activity calendar"""
    __regid__ = 'activities_box'

    visible = True # enabled by default
    title = _('My activities')
    order = 10

    def call(self, view=None, **kwargs):
        title = self._cw._(self.title)
        url = self._cw.build_url(rql="Any C WHERE R use_calendar CU, CU use_calendar C, "
                                 "R euser U, U eid %s" % self._cw.user.eid)
        title += '&nbsp;&nbsp;<a href="%s" title="%s"><img alt="calendar icon" src="data/office-calendar.png"/> </a>' % (
            xml_escape(url), self._cw._('see my calendars'))
        box = BoxWidget(title, self.__regid__, islist=False,
                        escape=False)
        html = self._cw.user.view('user_activity_calendar', calid='selftid')
        box.append(BoxHtml(html))
        box.render(self.w)


class MyActionsBox(BoxTemplate):
    """display a box with util links"""
    __regid__ = 'my_actions_box'

    visible = True # enabled by default
    title = _('Mes actions')
    order = 2

    def call(self, view=None, **kwargs):
        req = self._cw
        title = req._(self.title)
        box = BoxWidget(title, self.__regid__, islist=False)
        html = u'<div class="boxContent"><ul class="sideBox">'
        res = req.user.default_resource
        if res:
            url = xml_escape(res.absolute_url())
            html += u'<li><a class="boxManage" href="%s">%s</a></li>' % (url, req._('my_space'))
        else:
            html += '<li>%s</li>' % (req._('no resource for user %s') % req.user.login)
        # select default calendar for currently logged user
        cal = req.execute('Any C ORDERBY T DESC LIMIT 1 WHERE R use_calendar CU, '
                          'CU use_calendar C, C title T, R euser U, U eid %(u)s',
                          {'u': req.user.eid})
        if cal:
            url = xml_escape(req.build_url('view', etype='Timeperiod', vid='creation',
                                           __linkto='periods:%s:object' % cal[0][0]))
            html += u'<li><a class="boxManage" href="%s">%s</a></li>' % (url, req._('ask_off_days'))
        html += u'</ul></div>'
        box.append(BoxHtml(html))
        box.render(self.w)



from cubicweb.selectors import is_instance
from cubicweb.web.views import autoform
from cubicweb.web import INTERNAL_FIELD_VALUE, uicfg, formfields as ff
from cubicweb.web.formwidgets import HiddenInput

_afs = uicfg.autoform_section
_afs.tag_attribute(('WorkOrder', 'progress_target'), 'main', 'hidden')
_afs.tag_attribute(('WorkOrder', 'progress_todo'), 'main', 'hidden')
_afs.tag_attribute(('WorkOrder', 'progress_done'), 'main', 'hidden')
_afs.tag_subject_of(('Resource', 'use_calendar', '*'), 'main', 'inlined')

_affk = uicfg.autoform_field_kwargs


def tp_periods_choices(form, field, limit=None):
    #voc = self.object_relation_vocabulary(rtype, limit)
    if form._cw.form.get('vid') == 'holidays_form':
        rset = form._cw.execute("Any C WHERE R use_calendar CU, CU use_calendar C, "
                                "R euser U, U eid %(u)s", {'u':form._cw.user.eid})
        return sorted((v.view('combobox'), unicode(v.eid))
                      for v in rset.entities())
    return field.__class__.choices(field, form, limit=limit)
_affk.tag_object_of(('*', 'periods', 'Timeperiod'),
                    {'choices': tp_periods_choices})

def tp_day_type_choices(form, field, limit=None):
    voc = field.__class__.choices(field, form, limit=limit)
    if form._cw.form.get('vid') == 'holidays_form':
        voc = [item for item in voc
               if item[0] in form.conges_days]
    return voc
_affk.tag_subject_of(('Timeperiod', 'day_type', '*'),
                     {'choices': tp_day_type_choices})



def activity_done_by_choices(form, field, limit=None):
    user = form._cw.user
    entity = form.edited_entity
    # managers can edit the done_by relation as they wish
    if user.is_in_group('managers'):
        rql = 'Any R,T '
        if limit is not None:
            rql += 'LIMIT %s ' % limit
        rql += 'WHERE R is Resource, R title T'
        return sorted((entity.view('combobox'), unicode(entity.eid))
                      for entity in form._cw.execute(rql).entities())
    # users can't edit an existing done_by relation
    if entity.has_eid():
        return []
    rql = 'Any R,T WHERE R euser U, R title T, U eid %(u)s'
    res = form._cw.execute(rql, {'u': user.eid}).get_entity(0, 0)
    return [(res.view('combobox'), unicode(res.eid))]
_affk.tag_subject_of(('Activity', 'done_by', '*'),
                     {'choices': activity_done_by_choices})

def activity_done_for_choices(form, field, limit=None):
    req = form._cw
    user = req.user
    entity = form.edited_entity
    options = []
    open_state = req.vreg['etypes'].etype_class('WorkOrder').open_state
    # managers can edit the done_for relation as they wish
    if user.is_in_group('managers'):
        if limit is None:
            limit = ''
        else:
            limit = ' LIMIT %s' % limit
        rql = ('Any WO,T %s WHERE WO is WorkOrder, WO title T, '
               'WO in_state S, S name "%s"' % (limit, open_state))
        rset = form._cw.execute(rql)
        if rset:
            options += [(req._('workorders in state %s') % req._(open_state), None)]
            options += sorted((entity.view('combobox'), unicode(entity.eid))
                              for entity in rset.entities())
        else:
            options += [(req._('no workorders in state %s') % req._(open_state),
                         INTERNAL_FIELD_VALUE)]
        return options
    # for new entities, users will only see their matching resource
    rql = ('DISTINCT Any WO,T WHERE WO is WorkOrder, WO title T, '
           'WO in_state S, S name %(s)s, '
           'WO todo_by R, R euser U')
    rset = req.execute(rql+', U eid %(u)s', {'u': req.user.eid,
                                             's': open_state})
    if rset:
        options += [(req._('your workorders'), None)]
        options += sorted((entity.view('combobox'), unicode(entity.eid))
                          for entity in rset.entities())
    rset = req.execute(rql+', NOT U eid %(u)s', {'u': req.user.eid,
                                                 's': open_state})
    if rset:
        options += [(req._('other workorders'), None)]
        options += sorted((entity.view('combobox'), unicode(entity.eid))
                          for entity in rset.entities())
    if not options:
        options += [(req._('no workorders'),
                     INTERNAL_FIELD_VALUE)]
    return options
_affk.tag_subject_of(('Activity', 'done_for', '*'),
                     {'choices': activity_done_for_choices})



import datetime
from urlparse import urlparse

from logilab.mtconverter import xml_escape
from logilab.common.date import date_range, previous_month, next_month

from rql.utils import rqlvar_maker

from cubicweb.view import AnyRsetView, EntityView
from cubicweb.selectors import match_form_params, is_instance, one_line_rset
from cubicweb.uilib import toggle_action
from cubicweb.web import INTERNAL_FIELD_VALUE, stdmsgs, form

from cubes.calendar.views.main import (get_date_range_from_req, WORKING_DAYS,
                                       WORKING_AM_DAYS, WORKING_PM_DAYS)
from cubes.calendar.entities import BadCalendar

WORKING_HALF_DAYS = list(WORKING_AM_DAYS) + list(WORKING_PM_DAYS)


class CWUserActivitySummaryView(EntityView):
    __regid__ = 'euser-stats'
    __select__ = match_form_params('start', 'stop') & is_instance('CWUser')

    def cell_call(self, row, col):
        _ = self._cw._
        entity = self.cw_rset.get_entity(row, col)
        start = strptime(self._cw.form['start'], '%Y-%m-%d')
        stop = strptime(self._cw.form['stop'], '%Y-%m-%d')
        self.w(u'<h1>%s %s</h1>' % (_('statisitics for user'), self._cw.user.login))
        self.w(u'<div class="actsum"><table class="listing"><tr>')
        self.w(u'<th>%s</th><th>%s</th><th>%%</th>' %
               (_('project'), _('days worked')))
        self.w(u'</tr><tr>')
        total_days = 0
        # select workcases' activities
        rql = ("Any W, SUM(DUR) WHERE A is Activity, A done_by R, "
               "R euser U, U eid %(x)s, A diem >= %(start)s, "
               "A diem < %(stop)s, A duration DUR, A wp WP, W split_into WP GROUPBY W")
        wactivities = self._cw.execute(rql, {'x' : entity.eid,
                                             'start' : start, 'stop' : stop})
        if wactivities:
            total_days += sum(dur for __, dur in wactivities)
        # select projects' activities
        rql = ("Any P, SUM(DUR) WHERE A is Activity, A done_by R, "
               "R euser U, U eid %(x)s,A diem >= %(start)s, "
               "A diem < %(stop)s, A duration DUR, A wp WP, WP version_of P GROUPBY P")
        pactivities = self._cw.execute(rql, {'x' : entity.eid,
                                             'start' : start, 'stop' : stop})
        if pactivities:
            total_days += sum(dur for __, dur in pactivities)
        for acts in (wactivities, pactivities):
            for row, (__, dur) in enumerate(acts):
                self.w(u'<tr>')
                self.w(u'<td>%s</td><td>%s</td><td>%s</td>' % (
                    self.view('incontext', acts, row=row, col=0), dur,
                    (100. * dur / total_days)))
                self.w(u'</tr>')
        self.w(u'</table></div>')


class CWUserActivitySubmitFormView(form.FormViewMixIn, EntityView):
    __regid__ = 'euser-activities-submitform'
    __select__ = one_line_rset() & is_instance('CWUser')
    domid = 'activityForm'

    def cell_call(self, row, col, year=None, month=None, day=None, **kwargs):
        self._cw.add_css('cubicweb.form.css')
        user = self.cw_rset.get_entity(row, col)
        if year and month and day:
            date = datetime.date(int(year), int(month), int(day))
        else:
            date = datetime.date.today()
        kwargs.setdefault('diem', date)
        self.w(u'<h2>%s</h2>' % self._cw._('declare activities').capitalize())
        self._make_activity_form(user, **kwargs)

    def _make_activity_form(self, cwuser, **formvalues):
        resource = cwuser.default_resource
        if resource is None:
            return u'<div class="error">%s</div>' % (
                self._cw._('no resource for user %s') % cwuser.login)
        display_fields = [('diem', 'subject'), ('duration', 'subject'),
                          ('done_for', 'subject'), ('description', 'subject'),
                          ('done_by', 'subject')]
        vreg = self._cw.vreg
        activity = vreg['etypes'].etype_class('Activity')(self._cw)
        activity.eid = self._cw.varmaker.next()
        form = vreg['forms'].select('edition', self._cw, entity=activity,
                                    display_fields=display_fields,
                                    redirect_path=self._cw.relative_path(False))
        form.form_buttons = form.form_buttons[:1] # only keep ok button
        renderer = vreg['formrenderers'].select_or_none('htable', self._cw)
        formvalues.setdefault('done_by', resource.eid)
        self.w(form.render(formvalues=formvalues, renderer=renderer))



class EuserMonitorCalendar(EntityView):
    __regid__ = 'user_activity_calendar'
    __select__ = is_instance('CWUser',)

    def cell_call(self, row, col, year=None, month=None, calid=None):
        self._cw.add_js('cubicweb.ajax.js')
        self._cw.add_css('cubes.calendar.css')
        user = self.cw_rset.get_entity(row, col)
        calid = calid or 'tid%s' % user.eid
        firstday, lastday = get_date_range_from_req(self._cw, year, month)

        # make calendar
        caption = '%s %s' % (self._cw._(firstday.strftime('%B').lower()), firstday.year)
        prevurl, nexturl = self._prevnext_links(firstday, user, calid)
        prevlink = '<a href="%s">&lt;&lt;</a>' % xml_escape(prevurl)
        nextlink = '<a href="%s">&gt;&gt;</a>' % xml_escape(nexturl)

        # build cells
        try:
            celldatas = self._build_activities(user, firstday, lastday)
        except BadCalendar, exc: # in case of missing week day information
            self.w(u'<div class="error">%s</div>' % exc)
            return
        # build table/header
        self.w(u'<table id="%s" class="activitiesCal">'
               u'<tr><th class="prev">%s</th>'
               u'<th class="calTitle" colspan="5"><span>%s</span></th>'
               u'<th class="next">%s</th></tr>'
               u'<tr><th>L</th><th>M</th><th>M</th><th>J</th><th>V</th><th>S</th><th>D</th></tr>'
               % (calid, prevlink, caption, nextlink))
        start = firstday - datetime.timedelta(firstday.weekday())
        # date range exclude last day so we should add one day, hence the 7
        stop = lastday + datetime.timedelta(7 - lastday.weekday())
        for curdate in date_range(start, stop):
            if curdate == start or curdate.weekday() == 0: # sunday
                self.w(u'<tr>')
            self._build_calendar_cell(curdate, celldatas, firstday)
            if curdate.weekday() == 6:
                self.w(u'</tr>')
        self.w(u'</table>')

    def _build_calendar_cell(self, curdate, celldatas, firstday):
        if curdate.month != firstday.month:
            self.w(u'<td class="outofrange"></td>')
        else:
            cssclasses, total_duration, url, workcases = celldatas[curdate]
            total = total_duration
            if workcases:
                total = u"%s (%s)" % (total, workcases)
            cellcontent = u'<a title="total %s" href="%s">%s</a>' % (
                total, url, curdate.day)
            self.w(u'<td class="%s">%s</td>' % (u' '.join(cssclasses),  cellcontent))

    def _prevnext_links(self, curdate, user, calid):
        prevdate = previous_month(curdate)
        nextdate = next_month(curdate)
        rql = 'Any X WHERE X eid %s' % user.eid
        prevlink = self._cw.ajax_replace_url(calid, rql=rql, vid='user_activity_calendar',
                                             replacemode='swap',
                                             month=prevdate.month, year=prevdate.year)
        nextlink = self._cw.ajax_replace_url(calid, rql=rql,vid= 'user_activity_calendar',
                                             replacemode='swap',
                                             month=nextdate.month, year=nextdate.year)
        return prevlink, nextlink

    def _build_activities(self, user, firstday, lastday):
        # figure out which days of month are working days
        resource = user.default_resource
        if resource:
            day_types = dict((date, (dtype, state)) for date, dtype, state in
                             user.reverse_euser[0].get_day_types(firstday, lastday))
        else:
            day_types = {}
        working_dtype = {}
        for eid, state in set(day_types.values()):
            working_dtype[eid] = self._cw.eid_rset(eid).get_entity(0, 0)

        # get activities
        activities = {}
        workcases = {}
        pending_activities = set()
        rql = ("Any DI,DU,S,WR WHERE A is Activity, "
               "  A in_state ST, ST name S, "
               "  A diem <= %(l)s, A diem >= %(f)s, "
               "  A diem DI, A duration DU, "
               "  A done_by R, R euser U, U eid %(u)s, "
               "  A done_for WO, W split_into WO, W title WR")
        rset = self._cw.execute(rql, {'u': user.eid, 'l': lastday, 'f': firstday})
        for diem, duration, state, workcase in rset:
            activities.setdefault(diem, 0)
            workcases.setdefault(diem, [])
            activities[diem] += float(duration)
            workcases[diem].append(workcase)
            if state == 'pending':
                pending_activities.add(diem)

        # build result
        celldatas = {}
        _today = datetime.date.today()
        # date range exclude last day so we should add one day, hence the 7
        for date_ in date_range(firstday, lastday + datetime.timedelta(days=1)):
            cssclass = []
            total_duration = activities.get(date_, 0.)
            dtype, state = day_types.get(date_, (None, None))
            if state == 'pending':
                cssclass.append(u'daytype_pending')
            if dtype and working_dtype[dtype].work_during:
                if date_ <= _today:
                    dtype_title = working_dtype[dtype].title
                    if ((total_duration != 1. and  dtype_title in WORKING_DAYS) or
                        (total_duration != 0.5 and dtype_title in WORKING_HALF_DAYS)):
                        cssclass.append(u'problem')
                    else:
                        if date_ in pending_activities:
                            cssclass.append(u'pending')
                        else:
                            cssclass.append(u'completed')
                    if dtype_title in WORKING_DAYS:
                        total_duration = u'%s / 1.0' % total_duration
                    elif dtype_title in WORKING_HALF_DAYS:
                        total_duration = u'%s / 0.5' % total_duration
                else:
                    if total_duration:
                        cssclass.append(u'problem')
            else:
                if state != 'pending':
                    cssclass.append(u'closed')
                if total_duration:
                    cssclass.append(u'problem')
            a_rql = ("Any A WHERE A is Activity, A diem = '%(d)s', "
                     "A done_by R, R euser U, U eid %(u)s"
                     % {'u': user.eid, 'd': date_.strftime('%Y-%m-%d')})
            url = xml_escape(self._cw.build_url('activities/%s/%s' % (user.login, date_.strftime('%Y-%m-%d'))))
            workcases_str = ','.join(workcases.get(date_, ''))
            celldatas[date_] = (cssclass, total_duration, url, workcases_str)
        if _today in celldatas:
            # celldatas maps days to tuples (cssclass, duration, url, descr)
            celldatas[_today][0].append(u'today')
        return celldatas



# -*- coding: utf-8 -*-
"""
:organization: Logilab
:copyright: 2009-2010 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
"""
__docformat__ = "restructuredtext en"

from cubicweb.selectors import is_instance
from cubicweb.server.hook import Hook, match_rtype

class ActivityProgressHook(Hook):
    __regid__ = 'timesheet_update_activity'
    __select__ = Hook.__select__ & is_instance('Activity')
    events = ('after_update_entity', )

    def __call__(self):
        self.entity.done_for[0].update_progress()

class DoneforProgressHook(Hook):
    __regid__ = 'timesheet_update_done_for'
    __select__ = Hook.__select__ & match_rtype('done_for')
    events = ('after_add_relation', 'after_delete_relation',)

    def __call__(self):
        self._cw.entity_from_eid(self.eidto).update_progress()




# pylint: disable-msg=W0622
"""cubicweb-timesheet application packaging information"""

modname = 'timesheet'
distname = 'cubicweb-%s' % modname

numversion = (0, 3, 0)
version = '.'.join(str(num) for num in numversion)

license = 'LGPL'
description = 'record who did what and when for the CubicWeb framework'
web = 'http://www.cubicweb.org/project/%s' % distname
author = 'Logilab'
author_email = 'contact@logilab.fr'
classifiers = [
           'Environment :: Web Environment',
           'Framework :: CubicWeb',
           'Programming Language :: Python',
           'Programming Language :: JavaScript',
           ]

__depends__ = {'cubicweb': '>= 3.9.0',
               'cubicweb-calendar':  '>= 0.1.0',
               'cubicweb-workorder': '>= 0.6.0',
               }


# packaging ###

from os import listdir as _listdir
from os.path import join, isdir
from glob import glob

THIS_CUBE_DIR = join('share', 'cubicweb', 'cubes', modname)

def listdir(dirpath):
    return [join(dirpath, fname) for fname in _listdir(dirpath)
            if fname[0] != '.' and not fname.endswith('.pyc')
            and not fname.endswith('~')
            and not isdir(join(dirpath, fname))]

data_files = [
    # common files
    [THIS_CUBE_DIR, [fname for fname in glob('*.py') if fname != 'setup.py']],
    ]
# check for possible extended cube layout
for dirname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'i18n', 'migration', 'wdoc'):
    if isdir(dirname):
        data_files.append([join(THIS_CUBE_DIR, dirname), listdir(dirname)])
# Note: here, you'll need to add subdirectories if you want
# them to be included in the debian package
